@@ -1,8 +1,8 @@
-from typing import Callable
+from typing import Callable, List
 
 from starlette.requests import Request
 
-KeyExtractorFn = Callable[[Request], list[str]]
+KeyExtractorFn = Callable[[Request], List[str]]
 
 
 class KeyExtractor:
@@ -10,7 +10,7 @@ class KeyExtractor:
         self.prefix = prefix
         self.fn = fn
 
-    def extract(self, req: Request) -> list[str]:
+    def extract(self, req: Request) -> List[str]:
         keys = self.fn(req)
         return [f'{self.prefix}@{key}' for key in keys]
 
